<?php
/**
 ------------------------------------------------------------------------
 SOLIDRES - Accommodation booking extension for Joomla
 ------------------------------------------------------------------------
 * @author    Solidres Team <contact@solidres.com>
 * @website   https://www.solidres.com
 * @copyright Copyright (C) 2013 Solidres. All Rights Reserved.
 * @license   GNU General Public License version 3, or later
 ------------------------------------------------------------------------
 */

/*
 * This layout file can be overridden by copying to:
 *
 * /templates/TEMPLATENAME/html/com_solidres/reservationasset/default.php
 *
 * However, occasionally we will need to update template/layout related files and it is the template developers'
 * responsibility to update the overridden files (if any) to maintain full compatibility with Solidres.
 *
 * We do not provide support if any of the overridden files are out of date and are not compatible with Solidres.
 *
 * @version 2.8.0
 */

defined('_JEXEC') or die;

use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Factory as CMSFactory;

if (SR_ISJ3)
{
	HTMLHelper::_('behavior.tabstate');
}

?>
<div id="solidres" class="<?php echo SR_UI ?> reservation_asset_default <?php echo SR_LAYOUT_STYLE ?>">
    <?php if (!empty($this->checkin) && !empty($this->checkout)) : ?>
    <div class="booking-summary">
        <div class="fcol">
            <p class="<?php echo $this->item->roomsOccupancyOptionsCount > 0 ? 'dline' : 'sline' ?>">
                <?php echo JText::sprintf('SR_BOOKING_SUMMARY_DATES', $this->checkinFormatted, $this->checkoutFormatted) ?>
            </p>
	        <?php if ($this->item->roomsOccupancyOptionsCount > 0) : ?>
            <p class="<?php echo $this->item->roomsOccupancyOptionsCount > 0 ? 'dline last' : 'sline' ?>">
	            <?php echo JText::sprintf('SR_BOOKING_SUMMARY_GUESTS', $this->item->roomsOccupancyOptionsAdults, $this->item->roomsOccupancyOptionsChildren) ?>
            </p>
	        <?php endif ?>
        </div>
        <div class="scol">
            <p class="sr-align-center"><a href="javascript:void(0)" class="open-overlay"><span class="overview-cost-grandtotal">0</span> <i class="fa fa-chevron-down"></i></a></p>
        </div>
    </div>
    <?php endif ?>
    <div class="reservation_asset_item clearfix">
		<?php if ($this->item->params['only_show_reservation_form'] == 0 && !$this->isAmending) : ?>
            <div class="<?php echo SR_UI_GRID_CONTAINER ?>">
                <div class="<?php echo SR_UI_GRID_COL_9 ?>">
                    <h1>
						<?php echo $this->escape($this->item->name) . ' '; ?>
						<?php
                        if ($this->item->rating > 0) :
                            echo '<span class="rating-wrapper">' . str_repeat('<i class="rating fa fa-star"></i> ', $this->item->rating) . '</span>';
                        endif;
                        ?>
                    </h1>
                </div>
                <div class="<?php echo SR_UI_GRID_COL_3 ?>">
					<?php echo $this->events->afterDisplayAssetName; ?>
                </div>
            </div>
            <div class="<?php echo SR_UI_GRID_CONTAINER ?>">
                <div class="<?php echo SR_UI_GRID_COL_12 ?>">
					<span class="address_1 reservation_asset_subinfo">
					<?php
					echo $this->item->address_1 . ', ' .
						(!empty($this->item->city) ? $this->item->city . ', ' : '') .
						(!empty($this->item->geostate_code_2) ? $this->item->geostate_code_2 . ' ' : '') .
						(!empty($this->item->postcode) ? $this->item->postcode . ', ' : '') .
						$this->item->country_name
					?>
                        <a class="show_map"
                           href="<?php echo Route::_('index.php?option=com_solidres&task=map.show&id=' . $this->item->id) ?>">
							<?php echo Text::_('SR_SHOW_MAP') ?>
						</a>
					</span>

					<?php if (!empty($this->item->address_2)) : ?>
                        <span class="address_2 reservation_asset_subinfo">
						<?php echo $this->item->address_2; ?>
					</span>
					<?php endif ?>

					<?php if (!empty($this->item->phone)) : ?>
                        <span class="phone reservation_asset_subinfo">
						<?php echo Text::_('SR_PHONE') . ': <a href="tel:' . $this->item->phone . '">' . $this->item->phone . '</a>'; ?>
					</span>
					<?php endif ?>

					<?php if (!empty($this->item->fax)) : ?>
                        <span class="fax reservation_asset_subinfo">
						<?php echo Text::_('SR_FAX') . ': ' . $this->item->fax; ?>
					</span>
					<?php endif ?>

                    <span class="social_network reservation_asset_subinfo clearfix">
						<?php
                        $socialNetworks = ['facebook', 'twitter', 'instagram', 'linkedin', 'pinterest', 'slideshare', 'vimeo', 'youtube'];
                        $socialIconsSuffixes = ['instagram' => ''];

                        foreach ($socialNetworks as $socialNetwork) :
	                        if (!empty($this->item->reservationasset_extra_fields[$socialNetwork . '_link'])
		                        && $this->item->reservationasset_extra_fields[$socialNetwork . '_show'] == 1) :
                                echo '<a href="' . $this->item->reservationasset_extra_fields[$socialNetwork . '_link'] .'"
                                   target="_blank">
                                   <i class="fa fa-' . $socialNetwork . ($socialIconsSuffixes[$socialNetwork] ?? '-square') . '"></i> 
                                   </a>';
	                        endif;
                        endforeach;
						?>

					</span>
                </div>
            </div>

            <div class="<?php echo SR_UI_GRID_CONTAINER ?>">
                <div class="<?php echo SR_UI_GRID_COL_12 ?>">
					<?php echo $this->defaultGallery; ?>
                </div>
            </div>

            <div class="<?php echo SR_UI_GRID_CONTAINER ?>">
                <div class="<?php echo SR_UI_GRID_COL_12 ?>">
					<?php
					echo HTMLHelper::_('bootstrap.startTabSet', 'asset-info', array('active' => 'asset-desc'));

					if (!empty($this->item->description) || !empty($this->item->facilities)) :
						echo HTMLHelper::_('bootstrap.addTab', 'asset-info', 'asset-desc', Text::_('SR_DESCRIPTION', true));

						$regex = '#<hr(.*)id="system-readmore"(.*)\/>#iU';
						$intro = $full = '';

						if (preg_match($regex, $this->item->description))
						{
							list($intro, $full) = preg_split($regex, $this->item->description, 2);

							echo $intro . '<a href="javascript:void(0)" data-toggle="modal" data-bs-toggle="modal" data-target="#property_desc" data-bs-target="#property_desc">' . Text::_('SR_READMORE') . '</a>';

							echo HTMLHelper::_(
								'bootstrap.renderModal',
								'property_desc',
								[
									'title'  => Text::_('SR_ABOUT_THIS_SPACE'),
									'footer' => '<button type="button" class="btn btn-secondary" data-dismiss="modal" data-bs-dismiss="modal" aria-hidden="true">'
										. Text::_("JLIB_HTML_BEHAVIOR_CLOSE") . '</button>'
								],
								$intro . $full
							);
						}
						else
                        {
                            echo $this->item->description;
                        }

						if (!empty($this->item->facilities)) :
                            echo '<h3>' .  Text::_('SR_CUSTOMFIELD_FACILITIES') . '</h3>';
							echo SRLayoutHelper::render('facility.facility', array('facilities' => $this->item->facilities));
						endif;

						echo HTMLHelper::_('bootstrap.endTab');
					endif;

					if (isset($this->item->feedbacks->render) && !empty($this->item->feedbacks->render)) :
						echo HTMLHelper::_('bootstrap.addTab', 'asset-info', 'asset-feedback', Text::_('SR_REVIEWS', true));
						echo $this->item->feedbacks->render;
						echo HTMLHelper::_('bootstrap.endTab');

						echo HTMLHelper::_('bootstrap.addTab', 'asset-info', 'asset-feedback-scores', Text::_('SR_FEEDBACK_SCORES', true));
						echo $this->item->feedbacks->scores;
						echo HTMLHelper::_('bootstrap.endTab');
					endif;

					echo HTMLHelper::_('bootstrap.endTabSet');
					?>
                </div>
            </div>

		<?php endif ?>

		<?php echo $this->events->beforeDisplayAssetForm; ?>
		<?php if (SRPlugin::isEnabled('user') && $this->showLoginBox && !$this->isAmending) : ?>
            <div class="<?php echo SR_UI_GRID_CONTAINER ?>">
                <div class="<?php echo SR_UI_GRID_COL_12 ?>">
                    <div class="alert alert-info sr-login-form">
						<?php
						if (!CMSFactory::getUser()->get('id')) :
							echo $this->loadTemplate('login');
						else:
							echo $this->loadTemplate('userinfo');
						endif;
						?>
                    </div>
                </div>
            </div>
		<?php endif; ?>

        <div class="<?php echo SR_UI_GRID_CONTAINER ?>">
            <div class="<?php echo SR_UI_GRID_COL_12 ?>">
				<?php echo $this->loadTemplate('roomtype'); ?>
            </div>
        </div>

        <?php if (!$this->isAmending) : ?>
        <div class="<?php echo SR_UI_GRID_CONTAINER ?>">
            <div class="<?php echo SR_UI_GRID_COL_12 ?>">
				<?php echo $this->loadTemplate('information'); ?>
            </div>
        </div>
        <?php endif ?>

		<?php echo $this->events->afterDisplayAssetForm; ?>
		<?php if ($this->showPoweredByLink) : ?>
            <div class="<?php echo SR_UI_GRID_CONTAINER ?>">
                <div class="<?php echo SR_UI_GRID_COL_12 ?> powered">
                    <p>
                        Powered by <a target="_blank" title="Solidres - A hotel booking extension for Joomla"
                                      href="https://www.solidres.com">Solidres</a>
                    </p>
                </div>
            </div>
		<?php endif ?>
    </div>
</div>